@@ -111,6 +111,7 @@ About::About(QWidget * parent, Qt::WindowFlags f)
 		"Simon <hackykid@users.sourceforge.net>\n"
 		"Stanislav Maslovski <s_i_m@users.sourceforge.net>\n"
 		"Tanguy Krotoff <tkrotoff@gmail.com>\n"
+		"Stivo <helifan@users.sourceforge.net>\n"
 		).replace("<", "&lt;").replace(">", "&gt;") + 
 		"</pre>" +
 		tr("If there's any omission, please report.")
@@ -201,6 +202,8 @@ QString About::getTranslators() {
 		trad(tr("Arabic"), "Muhammad Nour Hajj Omar <arabianheart@live.com>") +
 		trad(tr("Kurdish"), "Si_murg56 <simurg56@gmail.com>") +
 		trad(tr("Galician"), "Miguel Branco <mgl.branco@gmail.com>") +
+		trad(tr("Vietnamese"), QString::fromUtf8("Lê Xuân Thảo <thaolx@gmail.com>")) +
+		trad(tr("Estonian"), QString::fromUtf8("Olav Mägi <olav.magi@hotmail.com>")) +
 #ifndef TRANS_TABLE
         "</ul>");
 #else
