@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2009 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -32,13 +32,14 @@ public:
 	int fontsize;
 	unsigned int primarycolor;
 	unsigned int backcolor;
+	unsigned int outlinecolor;
 	bool bold;
 	bool italic;
 	int halignment;
 	int valignment;
 	int borderstyle;
-	int outline;
-	int shadow;
+	double outline;
+	double shadow;
 	int marginl;
 	int marginr;
 	int marginv;
@@ -47,6 +48,7 @@ public:
 	void load(QSettings * set);
 
 	bool exportStyles(const QString & filename);
+	QString toString();
 };
 
 #endif
