@@ -52,6 +52,7 @@ class MyActionGroup;
 class PreferencesDialog;
 class MyServer;
 
+class TVList;
 
 class BaseGui : public QMainWindow
 {
@@ -173,6 +174,7 @@ protected slots:
 #if AUTODISABLE_ACTIONS
 	virtual void enableActionsOnPlaying();
 	virtual void disableActionsOnStop();
+	virtual void togglePlayAction(Core::State);
 #endif
 
 	virtual void resizeWindow(int w, int h);
@@ -220,6 +222,7 @@ protected slots:
 	virtual void remoteOpen(QString file);
 	virtual void remoteOpenFiles(QStringList files);
 	virtual void remoteAddFiles(QStringList files);
+	virtual void remoteLoadSubtitle(QString file);
 
 	//! Called when core can't parse the mplayer version and there's no
 	//! version supplied by the user
@@ -352,6 +355,7 @@ protected:
 	MyAction * compactAct;
 	MyAction * videoEqualizerAct;
 	MyAction * screenshotAct;
+	MyAction * screenshotsAct;
 	MyAction * videoPreviewAct;
 	MyAction * flipAct;
 	MyAction * mirrorAct;
@@ -360,9 +364,7 @@ protected:
 	MyAction * deblockAct;
 	MyAction * deringAct;
 	MyAction * addNoiseAct;
-#if NEW_ASPECT_CODE
 	MyAction * addLetterboxAct;
-#endif
 	MyAction * upscaleAct;
 
 	// Menu Audio
@@ -394,6 +396,7 @@ protected:
 	MyAction * useAssAct;
 	MyAction * useClosedCaptionAct;
 	MyAction * useForcedSubsOnlyAct;
+	MyAction * subVisibilityAct;
 	MyAction * showFindSubtitlesDialogAct;
 	MyAction * openUploadSubtitlesPageAct;//turbos  
 
@@ -443,9 +446,8 @@ protected:
 	MyAction * resetVideoEqualizerAct;
 	MyAction * resetAudioEqualizerAct;
 	MyAction * showContextMenuAct;
-#if NEW_ASPECT_CODE
 	MyAction * nextAspectAct;
-#endif
+	MyAction * nextWheelFunctionAct;
 
 	// Moving and zoom
 	MyAction * moveUpAct;
@@ -496,22 +498,16 @@ protected:
 	// Aspect Action Group
 	MyActionGroup * aspectGroup;
 	MyAction * aspectDetectAct;
-#if NEW_ASPECT_CODE
 	MyAction * aspectNoneAct;
-	MyAction * aspect11Act; // 1:1
-#endif
-	MyAction * aspect43Act;
-	MyAction * aspect54Act;
-	MyAction * aspect149Act;
-	MyAction * aspect169Act;
-	MyAction * aspect1610Act;
-	MyAction * aspect235Act;
-#if !NEW_ASPECT_CODE
-	MyAction * aspect43LetterAct;
-	MyAction * aspect169LetterAct;
-	MyAction * aspect43PanscanAct;
-	MyAction * aspect43To169Act;
-#endif
+	MyAction * aspect11Act;		// 1:1
+	MyAction * aspect32Act;		// 3:2
+	MyAction * aspect43Act;		// 4:3
+	MyAction * aspect54Act;		// 5:4
+	MyAction * aspect149Act;	// 14:9
+	MyAction * aspect1410Act;	// 14:10
+	MyAction * aspect169Act;	// 16:9
+	MyAction * aspect1610Act;	// 16:10
+	MyAction * aspect235Act;	// 2.35:1
 
 	// Rotate Group
 	MyActionGroup * rotateGroup;
@@ -548,6 +544,9 @@ protected:
 	MyAction * rightChannelAct;
 
 	// Other groups
+#if PROGRAM_SWITCH
+	MyActionGroup * programTrackGroup;
+#endif
 	MyActionGroup * videoTrackGroup;
 	MyActionGroup * audioTrackGroup;
 	MyActionGroup * subtitleTrackGroup;
@@ -577,6 +576,9 @@ protected:
 	QMenu *helpMenu;
 
 	QMenu * subtitlestrack_menu;
+#if PROGRAM_SWITCH
+	QMenu * programtrack_menu;
+#endif
 	QMenu * videotrack_menu;
 	QMenu * audiotrack_menu;
 	QMenu * titles_menu;
@@ -621,6 +623,9 @@ protected:
 
 	MyServer * server;
 
+	TVList * tvlist;
+	TVList * radiolist;
+
 	QStringList actions_list;
 
 	QString pending_actions_to_run;
