@@ -35,6 +35,7 @@
 #include "constants.h"
 #include "colorutils.h"
 #include "discname.h"
+#include "filters.h"
 
 #ifdef Q_OS_WIN
 #include <windows.h> // To change app priority
@@ -47,6 +48,7 @@
 #ifndef NO_USE_INI_FILES
 #include "filesettings.h"
 #include "filesettingshash.h"
+#include "tvsettings.h"
 #endif
 
 using namespace Global;
@@ -65,21 +67,17 @@ Core::Core( MplayerWindow *mpw, QWidget* parent )
 	just_unloaded_external_subs = false;
 	change_volume_after_unpause = false;
 
+#if DVDNAV_SUPPORT
+	dvdnav_title_is_menu = true; // Enabled by default for compatibility with previous versions of mplayer
+#endif
+
 #ifndef NO_USE_INI_FILES
 	// Create file_settings
-	#if NEW_SETTINGS_MANAGEMENT
 	file_settings = 0;
 	changeFileSettingsMethod(pref->file_settings_method);
-	#else
-	if (Paths::iniPath().isEmpty()) {	
-		file_settings = new QSettings(QSettings::IniFormat, QSettings::UserScope,
-                                      QString(COMPANY), QString("smplayer_files") );
-	} else {
-		QString filename = Paths::iniPath() + "/smplayer_files.ini";
-		file_settings = new QSettings( filename, QSettings::IniFormat );
-		qDebug("Core::Core: file_settings: '%s'", filename.toUtf8().data());
-	}
-	#endif
+
+	// TV settings
+	tv_settings = new TVSettings(Paths::iniPath());
 #endif
 
     proc = new MplayerProcess(this);
@@ -91,6 +89,14 @@ Core::Core( MplayerWindow *mpw, QWidget* parent )
 	connect( proc, SIGNAL(error(QProcess::ProcessError)),
              mplayerwindow->videoLayer(), SLOT(playingStopped()) );
 
+	// Necessary to hide/unhide mouse cursor on black borders
+	connect( proc, SIGNAL(processExited()),
+             mplayerwindow, SLOT(playingStopped()) );
+
+	connect( proc, SIGNAL(error(QProcess::ProcessError)),
+             mplayerwindow, SLOT(playingStopped()) );
+
+
 	connect( proc, SIGNAL(receivedCurrentSec(double)),
              this, SLOT(changeCurrentSec(double)) );
 
@@ -174,6 +180,11 @@ Core::Core( MplayerWindow *mpw, QWidget* parent )
 	QTimer * ask_timer = new QTimer(this);
 	connect( ask_timer, SIGNAL(timeout()), this, SLOT(askForInfo()) );
 	ask_timer->start(5000);
+
+	connect( proc, SIGNAL(receivedTitleIsMenu()),
+             this, SLOT(dvdTitleIsMenu()) );
+	connect( proc, SIGNAL(receivedTitleIsMovie()),
+             this, SLOT(dvdTitleIsMovie()) );
 #endif
 	
 	connect( this, SIGNAL(stateChanged(Core::State)), 
@@ -188,6 +199,11 @@ Core::Core( MplayerWindow *mpw, QWidget* parent )
 	// Mplayerwindow
 	connect( this, SIGNAL(aboutToStartPlaying()),
              mplayerwindow->videoLayer(), SLOT(playingStarted()) );
+
+	// Necessary to hide/unhide mouse cursor on black borders
+	connect( this, SIGNAL(aboutToStartPlaying()),
+             mplayerwindow, SLOT(playingStarted()) );
+
 #if DVDNAV_SUPPORT
 	connect( mplayerwindow, SIGNAL(mouseMoved(QPoint)), 
              this, SLOT(dvdnavUpdateMousePos(QPoint)) );
@@ -222,6 +238,7 @@ Core::~Core() {
 
 #ifndef NO_USE_INI_FILES
 	delete file_settings;
+	delete tv_settings;
 #endif
 
 #ifdef Q_OS_WIN
@@ -233,7 +250,6 @@ Core::~Core() {
 
 #ifndef NO_USE_INI_FILES 
 void Core::changeFileSettingsMethod(QString method) {
-#if NEW_SETTINGS_MANAGEMENT
 	qDebug("Core::changeFileSettingsMethod: %s", method.toUtf8().constData());
 	if (file_settings) delete file_settings;
 
@@ -241,7 +257,6 @@ void Core::changeFileSettingsMethod(QString method) {
 		file_settings = new FileSettingsHash(Paths::iniPath());
 	else
 		file_settings = new FileSettings(Paths::iniPath());
-#endif
 }
 #endif
 
@@ -282,31 +297,6 @@ void Core::reload() {
 }
 
 #ifndef NO_USE_INI_FILES
-#if !NEW_SETTINGS_MANAGEMENT
-
-bool Core::checkHaveSettingsSaved(QString group_name) {
-	qDebug("Core::checkHaveSettingsSaved: group_name: '%s'", group_name.toUtf8().data());
-
-	file_settings->beginGroup( group_name );
-	bool saved = file_settings->value( "saved", false ).toBool();
-	file_settings->endGroup();
-
-	return saved;
-}
-
-void Core::loadMediaInfo(QString group_name) {
-	qDebug("Core::loadMediaInfo: '%s'", group_name.toUtf8().data() );
-
-	file_settings->beginGroup( group_name );
-
-	/*mdat.load(*settings);*/
-	mset.load(file_settings);
-
-	file_settings->endGroup();
-}
-
-#endif // NEW_SETTINGS_MANAGEMENT
-
 void Core::saveMediaInfo() {
 	qDebug("Core::saveMediaInfo");
 
@@ -315,35 +305,14 @@ void Core::saveMediaInfo() {
 		return;
 	}
 
-#if NEW_SETTINGS_MANAGEMENT
 	if ( (mdat.type == TYPE_FILE) && (!mdat.filename.isEmpty()) ) {
 		file_settings->saveSettingsFor(mdat.filename, mset);
 	}
-#else
-	QString group_name;
-
-	/*
-	if ( (mdat.type == TYPE_DVD) && (!mdat.dvd_id.isEmpty()) ) {
-		group_name = dvdForPref( mdat.dvd_id, mset.current_title_id );
-	}
 	else
-	*/
-	if ( (mdat.type == TYPE_FILE) && (!mdat.filename.isEmpty()) ) {
-		group_name = FileSettings::filenameToGroupname( mdat.filename );
+	if ( (mdat.type == TYPE_TV) && (!mdat.filename.isEmpty()) ) {
+		tv_settings->saveSettingsFor(mdat.filename, mset);
 	}
-
-	if (!group_name.isEmpty()) {
-		file_settings->beginGroup( group_name );
-		file_settings->setValue( "saved", true);
-
-		/*mdat.save(*settings);*/
-		mset.save(file_settings);
-
-		file_settings->endGroup();
-	}
-#endif // NEW_SETTINGS_MANAGEMENT
 }
-
 #endif // NO_USE_INI_FILES
 
 void Core::initializeMenus() {
@@ -454,6 +423,11 @@ void Core::open(QString file, int seek) {
 			openAudioCD();
 		}
 	}
+	else
+	if ((file.toLower().startsWith("dvb:")) || (file.toLower().startsWith("tv:"))) {
+		qDebug("Core::open: * identified as TV");
+		openTV(file);
+	}
 	else {
 		qDebug("Core::open: * not identified, playing as stream");
 		openStream(file);
@@ -689,6 +663,60 @@ void Core::openDVD(QString dvd_url) {
 	initPlaying();
 }
 
+void Core::openTV(QString channel_id) {
+	qDebug("Core::openTV: '%s'", channel_id.toUtf8().constData());
+
+	if (proc->isRunning()) {
+		stopMplayer();
+		we_are_restarting = false;
+	}
+
+	// Save data of previous file:
+#ifndef NO_USE_INI_FILES
+	saveMediaInfo();
+#endif
+
+	// Use last channel if the name is just "dvb://" or "tv://"
+	if ((channel_id == "dvb://") && (!pref->last_dvb_channel.isEmpty())) {
+		channel_id = pref->last_dvb_channel;
+	}
+	else
+	if ((channel_id == "tv://") && (!pref->last_tv_channel.isEmpty())) {
+		channel_id = pref->last_tv_channel;
+	}
+
+	// Save last channel
+	if (channel_id.startsWith("dvb://")) pref->last_dvb_channel = channel_id;
+	else
+	if (channel_id.startsWith("tv://")) pref->last_tv_channel = channel_id;
+
+	mdat.reset();
+	mdat.filename = channel_id;
+	mdat.type = TYPE_TV;
+
+	mset.reset();
+
+	// Set the default deinterlacer for TV
+	mset.current_deinterlacer = pref->initial_tv_deinterlace;
+
+#ifndef NO_USE_INI_FILES
+	if (!pref->dont_remember_media_settings) {
+		// Check if we already have info about this file
+		if (tv_settings->existSettingsFor(channel_id)) {
+			qDebug("Core::openTV: we have settings for this file!!!");
+
+			// In this case we read info from config
+			tv_settings->loadSettingsFor(channel_id, mset);
+			qDebug("Core::openTV: media settings read");
+		}
+	}
+#endif
+
+	/* initializeMenus(); */
+
+	initPlaying();
+}
+
 void Core::openStream(QString name) {
 	qDebug("Core::openStream: '%s'", name.toUtf8().data());
 
@@ -736,20 +764,12 @@ void Core::playNewFile(QString file, int seek) {
 
 #ifndef NO_USE_INI_FILES
 	// Check if we already have info about this file
-	#if NEW_SETTINGS_MANAGEMENT
 	if (file_settings->existSettingsFor(file)) {
-	#else
-	if (checkHaveSettingsSaved( FileSettings::filenameToGroupname(file) )) {
-	#endif
 		qDebug("Core::playNewFile: We have settings for this file!!!");
 
 		// In this case we read info from config
 		if (!pref->dont_remember_media_settings) {
-			#if NEW_SETTINGS_MANAGEMENT
 			file_settings->loadSettingsFor(file, mset);
-			#else
-			loadMediaInfo( FileSettings::filenameToGroupname(file) );
-			#endif
 			qDebug("Core::playNewFile: Media settings read");
 
 			// Resize the window and set the aspect as soon as possible
@@ -982,19 +1002,17 @@ void Core::finishRestart() {
 
 	we_are_restarting = false;
 
-#if NEW_ASPECT_CODE
 	changeAspectRatio(mset.aspect_ratio_id);
-#else
-	if (mset.aspect_ratio_id < MediaSettings::Aspect43Letterbox) {
-		changeAspectRatio(mset.aspect_ratio_id);
-	}
-#endif
 
-	bool isMuted = mset.mute;
-	if (!pref->dont_change_volume) {
-		 setVolume( mset.volume, TRUE );
+	if (pref->global_volume) {
+		bool was_muted = pref->mute;
+		setVolume( pref->volume, true);
+		if (was_muted) mute(true);
+	} else {
+		bool was_muted = mset.mute;
+		 setVolume( mset.volume, true );
+		if (was_muted) mute(true);
 	}
-	if (isMuted) mute(TRUE);
 
 	if (pref->change_video_equalizer_on_startup && (mset.gamma != 0)) {
 		int gamma = mset.gamma;
@@ -1007,6 +1025,12 @@ void Core::finishRestart() {
 
 	changePanscan(mset.panscan_factor);
 
+	// Toggle subtitle visibility
+	changeSubVisibility(pref->sub_visibility);
+
+	// Initialize the OSD level
+	QTimer::singleShot(3000, this, SLOT(initializeOSD()));
+
 	emit mediaLoaded();
 	emit mediaInfoChanged();
 
@@ -1015,6 +1039,9 @@ void Core::finishRestart() {
 	qDebug("Core::finishRestart: --- end ---");
 }
 
+void Core::initializeOSD() {
+	changeOSD(pref->osd);
+}
 
 void Core::stop()
 {
@@ -1025,6 +1052,7 @@ void Core::stop()
 		// if pressed stop twice, reset video to the beginning
 		qDebug("Core::stop: mset.current_sec: %f", mset.current_sec);
 		mset.current_sec = 0;
+		qDebug("Core::stop: mset.current_sec set to 0");
 		emit showTime( mset.current_sec );
 #ifdef SEEKBAR_RESOLUTION
 		emit positionChanged( 0 );
@@ -1119,6 +1147,21 @@ void Core::screenshot() {
 	}
 }
 
+void Core::screenshots() {
+	qDebug("Core::screenshots");
+
+	if ( (!pref->screenshot_directory.isEmpty()) && 
+         (QFileInfo(pref->screenshot_directory).isDir()) ) 
+	{
+		tellmp( "screenshot 1");
+	} else {
+		qDebug("Core::screenshots: error: directory for screenshots not valid");
+		QString text = "Screenshots NOT taken, folder not configured";
+		tellmp("osd_show_text \"" + text + "\" 3000 1");
+		emit showMessage(text);
+	}
+}
+
 void Core::processFinished()
 {
     qDebug("Core::processFinished");
@@ -1126,8 +1169,8 @@ void Core::processFinished()
 #ifdef Q_OS_WIN
 #ifdef SCREENSAVER_OFF
 	// Restores the Windows screensaver
-	if (pref->disable_screensaver) {
-		win_screensaver->restore();
+	if (pref->turn_screensaver_off) {
+		win_screensaver->enable();
 	}
 #endif
 #endif
@@ -1197,7 +1240,7 @@ void Core::startMplayer( QString file, double seek ) {
 #ifdef Q_OS_WIN
 #ifdef SCREENSAVER_OFF
 	// Disable the Windows screensaver
-	if (pref->disable_screensaver) {
+	if (pref->turn_screensaver_off) {
 		win_screensaver->disable();
 	}
 #endif
@@ -1221,8 +1264,9 @@ void Core::startMplayer( QString file, double seek ) {
 	bool url_is_playlist = file.endsWith(IS_PLAYLIST_TAG);
 	if (url_is_playlist) file = file.remove( QRegExp(IS_PLAYLIST_TAG_RX) );
 
-	bool screenshot_enabled = ( (!pref->screenshot_directory.isEmpty()) && 
-                                 (QFileInfo(pref->screenshot_directory).isDir()) );
+	bool screenshot_enabled = ( (pref->use_screenshot) && 
+                                (!pref->screenshot_directory.isEmpty()) && 
+                                (QFileInfo(pref->screenshot_directory).isDir()) );
 
 	proc->clearArguments();
 
@@ -1245,6 +1289,10 @@ void Core::startMplayer( QString file, double seek ) {
 
 	proc->addArgument("-noquiet");
 
+	if (pref->verbose_log) {
+		proc->addArgument("-v");
+	}
+
 	if (pref->fullscreen && pref->use_mplayer_window) {
 		proc->addArgument("-fs");
 	} else {
@@ -1267,6 +1315,22 @@ void Core::startMplayer( QString file, double seek ) {
 		proc->addArgument("-vc");
 		proc->addArgument(mset.forced_video_codec);
 	}
+#ifndef Q_OS_WIN
+	else {
+		if (pref->vo.startsWith("vdpau")) {
+			proc->addArgument("-vc");
+			proc->addArgument("ffh264vdpau,ffmpeg12vdpau,ffwmv3vdpau,ffvc1vdpau,");
+		}
+#endif	
+		else {
+			if (pref->coreavc) {
+				proc->addArgument("-vc");
+				proc->addArgument("coreserve,");
+			}
+		}
+#ifndef Q_OS_WIN
+	}
+#endif
 
 	if (pref->use_hwac3) {
 		proc->addArgument("-afm");
@@ -1333,7 +1397,7 @@ void Core::startMplayer( QString file, double seek ) {
 	} else {
 		proc->addArgument("-vo");
 #ifdef Q_OS_WIN
-		if (QSysInfo::WindowsVersion == QSysInfo::WV_VISTA) {
+		if (QSysInfo::WindowsVersion >= QSysInfo::WV_VISTA) {
 			proc->addArgument("direct3d,");
 		} else {
 			proc->addArgument("directx,");
@@ -1408,6 +1472,11 @@ void Core::startMplayer( QString file, double seek ) {
 		proc->addArgument( QString::number( pref->autosync_factor ) );
 	}
 
+	if (pref->use_mc) {
+		proc->addArgument("-mc");
+		proc->addArgument( QString::number( pref->mc_value ) );
+	}
+
 	if (pref->use_direct_rendering) {
 		proc->addArgument("-dr");
 	} else {
@@ -1423,7 +1492,11 @@ void Core::startMplayer( QString file, double seek ) {
 #ifndef Q_OS_WIN
 	if (!pref->use_mplayer_window) {
 		proc->addArgument( "-input" );
-		proc->addArgument( "conf=" + Paths::dataPath() +"/input.conf" );
+		if (MplayerVersion::isMplayerAtLeast(29058)) {
+			proc->addArgument( "nodefault-bindings:conf=/dev/null" );
+		} else {
+			proc->addArgument( "conf=" + Paths::dataPath() +"/input.conf" );
+		}
 	}
 #endif
 
@@ -1565,6 +1638,18 @@ void Core::startMplayer( QString file, double seek ) {
 		proc->addArgument("-forcedsubsonly");
 	}
 
+#if PROGRAM_SWITCH
+	if ( (mset.current_program_id != MediaSettings::NoneSelected) /*&& 
+         (mset.current_video_id == MediaSettings::NoneSelected) && 
+         (mset.current_audio_id == MediaSettings::NoneSelected)*/ )
+	{
+		proc->addArgument("-tsprog");
+		proc->addArgument( QString::number( mset.current_program_id ) );
+	}
+	// Don't set video and audio track if using -tsprog
+	else {
+#endif
+
 	if (mset.current_video_id != MediaSettings::NoneSelected) {
 		proc->addArgument("-vid");
 		proc->addArgument( QString::number( mset.current_video_id ) );
@@ -1578,6 +1663,10 @@ void Core::startMplayer( QString file, double seek ) {
 		}
 	}
 
+#if PROGRAM_SWITCH
+	}
+#endif
+
 	if (!initial_subtitle.isEmpty()) {
 		mset.external_subtitles = initial_subtitle;
 		initial_subtitle = "";
@@ -1657,17 +1746,22 @@ void Core::startMplayer( QString file, double seek ) {
 	}
 
 	// Set volume, requires mplayer svn r27872
-	bool use_volume_option = (pref->use_volume_option == Preferences::Enabled);
-	if (pref->use_volume_option == Preferences::Detect) {
-		use_volume_option = (MplayerVersion::isMplayerAtLeast(27872));
-	}
-	if ((use_volume_option) && (!pref->dont_change_volume)) {
-		proc->addArgument("-volume");
-		// Note: mset.volume may not be right, it can be the volume of the previous video if
-		// playing a new one, but I think it's better to use anyway the current volume on
-		// startup than set it to 0 or something.
-		// The right volume will be set later, when the video starts to play.
-		proc->addArgument( QString::number( mset.volume ) );
+	bool use_volume_option = (MplayerVersion::isMplayerAtLeast(27872));
+
+	if (pref->global_volume) {
+		if (use_volume_option) {
+			proc->addArgument("-volume");
+			proc->addArgument( QString::number( pref->volume ) );
+		}
+	} else {
+		if (use_volume_option) {
+			proc->addArgument("-volume");
+			// Note: mset.volume may not be right, it can be the volume of the previous video if
+			// playing a new one, but I think it's better to use anyway the current volume on
+			// startup than set it to 0 or something.
+			// The right volume will be set later, when the video starts to play.
+			proc->addArgument( QString::number( mset.volume ) );
+		}
 	}
 
 
@@ -1716,6 +1810,7 @@ void Core::startMplayer( QString file, double seek ) {
 		case TYPE_STREAM 	: cache = pref->cache_for_streams; break;
 		case TYPE_VCD 		: cache = pref->cache_for_vcds; break;
 		case TYPE_AUDIO_CD	: cache = pref->cache_for_audiocds; break;
+		case TYPE_TV		: cache = pref->cache_for_tv; break;
 		default: cache = 0;
 	}
 
@@ -1731,14 +1826,18 @@ void Core::startMplayer( QString file, double seek ) {
 		proc->addArgument( QString::number( mset.speed ) );
 	}
 
-	// If seek < 5 it's better to allow the video to start from the beginning
-	if ((seek >= 5) && (!pref->loop)) {
-		proc->addArgument("-ss");
-		proc->addArgument( QString::number( seek ) );
+	if (mdat.type != TYPE_TV) {
+		// If seek < 5 it's better to allow the video to start from the beginning
+		if ((seek >= 5) && (!pref->loop)) {
+			proc->addArgument("-ss");
+			proc->addArgument( QString::number( seek ) );
+		}
 	}
 
+	// Enable the OSD later, to avoid a lot of messages to be
+	// printed on startup
 	proc->addArgument("-osdlevel");
-	proc->addArgument( QString::number( pref->osd ) );
+	proc->addArgument( 0 );
 
 	if (pref->use_idx) {
 		proc->addArgument("-idx");
@@ -1787,34 +1886,20 @@ void Core::startMplayer( QString file, double seek ) {
 		}
 	}
 
-#if !NEW_ASPECT_CODE
-	// Panscan (crop)
-	if (!mset.panscan_filter.isEmpty()) {
-		proc->addArgument( "-vf-add" );
-		proc->addArgument( mset.panscan_filter );
-	}
-
-	// Crop 4:3 to 16:9
-	if (!mset.crop_43to169_filter.isEmpty()) {
-		proc->addArgument( "-vf-add" );
-		proc->addArgument( mset.crop_43to169_filter );
-	}
-#endif
-
 	// Denoise
 	if (mset.current_denoiser != MediaSettings::NoDenoise) {
 		proc->addArgument("-vf-add");
 		if (mset.current_denoiser==MediaSettings::DenoiseSoft) {
-			proc->addArgument( "hqdn3d=2:1:2" );
+			proc->addArgument( pref->filters->item("denoise_soft").filter() );
 		} else {
-			proc->addArgument( "hqdn3d" );
+			proc->addArgument( pref->filters->item("denoise_normal").filter() );
 		}
 	}
 
 	// Deblock
 	if (mset.deblock_filter) {
 		proc->addArgument("-vf-add");
-		proc->addArgument( "pp=vb/hb" );
+		proc->addArgument( pref->filters->item("deblock").filter() );
 	}
 
 	// Dering
@@ -1835,7 +1920,7 @@ void Core::startMplayer( QString file, double seek ) {
 	// Addnoise
 	if (mset.noise_filter) {
 		proc->addArgument("-vf-add");
-		proc->addArgument( "noise=9ah:5ah" );
+		proc->addArgument( pref->filters->item("noise").filter() );
 	}
 
 	// Postprocessing
@@ -1848,7 +1933,6 @@ void Core::startMplayer( QString file, double seek ) {
 
 
 	// Letterbox (expand)
-#if NEW_ASPECT_CODE
 	if ((mset.add_letterbox) || (pref->fullscreen && pref->add_blackborders_on_fullscreen)) {
 		proc->addArgument("-vf-add");
 		proc->addArgument( QString("expand=:::::%1,harddup").arg( DesktopInfo::desktop_aspectRatio(mplayerwindow)) );
@@ -1858,17 +1942,6 @@ void Core::startMplayer( QString file, double seek ) {
 		// it will be harmless in mplayer. 
 		// Anyway, if you know a proper way to fix the problem, please tell me.
 	}
-#else
-	if (mset.letterbox == MediaSettings::Letterbox_43) {		
-		proc->addArgument("-vf-add");
-		proc->addArgument("expand=:::::4/3");
-	}
-	else
-	if (mset.letterbox == MediaSettings::Letterbox_169) {
-		proc->addArgument("-vf-add");
-		proc->addArgument("expand=:::::16/9");
-	}
-#endif
 
 	// Software equalizer
 	if ( (pref->use_soft_video_eq) ) {
@@ -1936,6 +2009,16 @@ void Core::startMplayer( QString file, double seek ) {
 		proc->addArgument("screenshot");
 	}
 
+
+	// VDPAU doesn't allow any video filters!
+#ifndef Q_OS_WIN
+	if (pref->vo.startsWith("vdpau")) {
+		proc->addArgument("-vf-clr");
+		qDebug("Core::startMplayer: vdpau doesn't allow any video filter. All have been removed.");
+	}
+#endif
+
+
 	// slices
 	if ((pref->use_slices) && (!force_noslices)) {
 		proc->addArgument("-slices");
@@ -1969,7 +2052,7 @@ void Core::startMplayer( QString file, double seek ) {
 
 	if (mset.volnorm_filter) {
 		if (!af.isEmpty()) af += ",";
-		af += "volnorm=2";
+		af += pref->filters->item("volnorm").filter();
 	}
 
 	bool use_scaletempo = (pref->use_scaletempo == Preferences::Enabled);
@@ -2111,7 +2194,7 @@ void Core::goToSec( double sec ) {
 
     if (sec < 0) sec = 0;
     if (sec > mdat.duration ) sec = mdat.duration - 20;
-    tellmp("seek " + QString::number(sec) + " 2");
+    tellmp("pausing_keep seek " + QString::number(sec) + " 2");
 }
 
 
@@ -2489,6 +2572,8 @@ void Core::setSpeed( double value ) {
 
 	mset.speed = value;
 	tellmp( "speed_set " + QString::number( value ) );
+
+	displayMessage( tr("Speed: %1").arg(value) );
 }
 
 void Core::incSpeed10() {
@@ -2538,26 +2623,33 @@ void Core::normalSpeed() {
 void Core::setVolume(int volume, bool force) {
 	qDebug("Core::setVolume: %d", volume);
 
-	if ((volume==mset.volume) && (!force)) return;
+	int current_volume = (pref->global_volume ? pref->volume : mset.volume);
 
-	mset.volume = volume;
-	if (mset.volume > 100 ) mset.volume = 100;
-	if (mset.volume < 0 ) mset.volume = 0;
+	if ((volume == current_volume) && (!force)) return;
+
+	current_volume = volume;
+	if (current_volume > 100) current_volume = 100;
+	if (current_volume < 0) current_volume = 0;
 
 	if (state() == Paused) {
 		// Change volume later, after quiting pause
 		change_volume_after_unpause = true;
 	} else {
-		tellmp("volume " + QString::number(volume) + " 1");
+		tellmp("volume " + QString::number(current_volume) + " 1");
 	}
 
-	//if (mset.mute) mute(TRUE);
-	mset.mute=false;
+	if (pref->global_volume) {
+		pref->volume = current_volume;
+		pref->mute = false;
+	} else {
+		mset.volume = current_volume;
+		mset.mute = false;
+	}
 
 	updateWidgets();
 
-	displayMessage( tr("Volume: %1").arg(mset.volume) );
-	emit volumeChanged( mset.volume );
+	displayMessage( tr("Volume: %1").arg(current_volume) );
+	emit volumeChanged( current_volume );
 }
 
 void Core::switchMute() {
@@ -2570,29 +2662,35 @@ void Core::switchMute() {
 void Core::mute(bool b) {
 	qDebug("Core::mute");
 
-	mset.mute = b;
-
-	int v = 0;
-	if (mset.mute) v = 1;
+	int v = (b ? 1 : 0);
 	tellmp( pausing_prefix() + " mute " + QString::number(v) );
 
+	if (pref->global_volume) {
+		pref->mute = b;
+	} else {
+		mset.mute = b;
+	}
+
 	updateWidgets();
 }
 
 void Core::incVolume() {
 	qDebug("Core::incVolume");
-	setVolume(mset.volume + 4);
+	int new_vol = (pref->global_volume ? pref->volume + 4 : mset.volume + 4);
+	setVolume(new_vol);
 }
 
 void Core::decVolume() {
 	qDebug("Core::incVolume");
-	setVolume(mset.volume-4);
+	int new_vol = (pref->global_volume ? pref->volume - 4 : mset.volume - 4);
+	setVolume(new_vol);
 }
 
 void Core::setSubDelay(int delay) {
 	qDebug("Core::setSubDelay: %d", delay);
 	mset.sub_delay = delay;
-	tellmp("sub_delay " + QString::number( (double) mset.sub_delay/1000 ) +" 1");
+	tellmp( pausing_prefix() + " sub_delay " + QString::number( (double) mset.sub_delay/1000 ) +" 1");
+	displayMessage( tr("Subtitle delay: %1 ms").arg(delay) );
 }
 
 void Core::incSubDelay() {
@@ -2608,7 +2706,8 @@ void Core::decSubDelay() {
 void Core::setAudioDelay(int delay) {
 	qDebug("Core::setAudioDelay: %d", delay);
 	mset.audio_delay = delay;
-	tellmp("audio_delay " + QString::number( (double) mset.audio_delay/1000 ) +" 1");
+	tellmp( pausing_prefix() + " audio_delay " + QString::number( (double) mset.audio_delay/1000 ) +" 1");
+	displayMessage( tr("Audio delay: %1 ms").arg(delay) );
 }
 
 void Core::incAudioDelay() {
@@ -2714,6 +2813,17 @@ void Core::decSubStep() {
 	tellmp("sub_step -1");
 }
 
+void Core::changeSubVisibility(bool visible) {
+	qDebug("Core::changeSubVisilibity: %d", visible);
+	pref->sub_visibility = visible;
+	tellmp(QString("sub_visibility %1").arg(pref->sub_visibility ? 1 : 0));
+
+	if (pref->sub_visibility) 
+		displayMessage( tr("Subtitles on") );
+	else
+		displayMessage( tr("Subtitles off") );
+}
+
 // Audio equalizer functions
 void Core::setAudioEqualizer(AudioEqualizerList values, bool restart) {
 	mset.audio_equalizer = values;
@@ -2944,17 +3054,19 @@ void Core::changeAudio(int ID, bool allow_restart) {
 			restartPlay(); 
 		} else {
 			tellmp("switch_audio " + QString::number(ID) );
-			//#ifdef Q_OS_WIN
 			// Workaround for a mplayer problem in windows,
 			// volume is too loud after changing audio.
 
 			// Workaround too for a mplayer problem in linux,
 			// the volume is reduced if using -softvol-max.
-			if (!pref->dont_change_volume) {
+
+			if (pref->global_volume) {
+				setVolume( pref->volume, true);
+				if (pref->mute) mute(true);
+			} else {
 				setVolume( mset.volume, true );
+				if (mset.mute) mute(true); // if muted, mute again
 			}
-			//#endif
-			if (mset.mute) mute(true); // if muted, mute again
 			updateWidgets();
 		}
 	}
@@ -2986,13 +3098,18 @@ void Core::changeVideo(int ID, bool allow_restart) {
 		bool need_restart = false;
 		if (allow_restart) {
 			// afaik lavf doesn't require to restart, any other?
-			need_restart = (mdat.demuxer != "lavf");
+			need_restart = ((mdat.demuxer != "lavf") && (mdat.demuxer != "mpegts"));
 		}
 
 		if (need_restart) {
 			restartPlay(); 
 		} else {
-			tellmp("set_property switch_video " + QString::number(ID) );
+			if (mdat.demuxer == "nsv") {
+				// Workaround a problem with the nsv demuxer
+				qWarning("Core::changeVideo: not calling set_property switch_video with nsv to prevent mplayer go crazy");
+			} else {
+				tellmp("set_property switch_video " + QString::number(ID) );
+			}
 		}
 	}
 }
@@ -3013,6 +3130,32 @@ void Core::nextVideo() {
 	}
 }
 
+#if PROGRAM_SWITCH
+void Core::changeProgram(int ID) {
+	qDebug("Core::changeProgram: %d", ID);
+
+	if (ID != mset.current_program_id) {
+		mset.current_program_id = ID;
+		tellmp("set_property switch_program " + QString::number(ID) );
+
+		tellmp("get_property switch_audio");
+		tellmp("get_property switch_video");
+
+		/*
+		mset.current_video_id = MediaSettings::NoneSelected;
+		mset.current_audio_id = MediaSettings::NoneSelected;
+
+		updateWidgets();
+		*/
+	}
+}
+
+void Core::nextProgram() {
+	qDebug("Core::nextProgram");
+	// Not implemented yet
+}
+
+#endif
 
 void Core::changeTitle(int ID) {
 	if (mdat.type == TYPE_VCD) {
@@ -3077,7 +3220,8 @@ void Core::changeChapter(int ID) {
 }
 
 int Core::firstChapter() {
-	if (MplayerVersion::isMplayerAtLeast(25391)) 
+	if ( (MplayerVersion::isMplayerAtLeast(25391)) && 
+         (!MplayerVersion::isMplayerAtLeast(29407)) ) 
 		return 1;
 	else
 		return 0;
@@ -3168,7 +3312,6 @@ void Core::changeAngle(int ID) {
 	}
 }
 
-#if NEW_ASPECT_CODE
 void Core::changeAspectRatio( int ID ) {
 	qDebug("Core::changeAspectRatio: %d", ID);
 
@@ -3190,13 +3333,64 @@ void Core::changeAspectRatio( int ID ) {
 }
 
 void Core::nextAspectRatio() {
-	int ID = mset.aspect_ratio_id + 1;
-	if (ID > MediaSettings:: Aspect11) ID = MediaSettings::AspectNone;
-	changeAspectRatio(ID);
+	// Ordered list
+	QList<int> s;
+	s << MediaSettings::AspectNone 
+      << MediaSettings::AspectAuto
+      << MediaSettings::Aspect11	// 1
+      << MediaSettings::Aspect54	// 1.25
+      << MediaSettings::Aspect43	// 1.33
+      << MediaSettings::Aspect1410	// 1.4
+      << MediaSettings::Aspect32	// 1.5
+      << MediaSettings::Aspect149	// 1.55
+      << MediaSettings::Aspect1610	// 1.6
+      << MediaSettings::Aspect169	// 1.77
+      << MediaSettings::Aspect235;	// 2.35
 
+	int i = s.indexOf( mset.aspect_ratio_id ) + 1;
+	if (i >= s.count()) i = 0;
+
+	int new_aspect_id = s[i];
+
+	changeAspectRatio( new_aspect_id );
 	updateWidgets();
 }
 
+void Core::nextWheelFunction() {
+	int a = pref->wheel_function;
+
+	bool done = false;
+	if(((int ) pref->wheel_function_cycle)==0)
+		return;
+	while(!done){
+		// get next a
+
+		a = a*2;
+		if(a==32)
+			a = 2;
+		// See if we are done
+		if(pref->wheel_function_cycle.testFlag(QFlag(a)))
+			done = true;
+	}
+	pref->wheel_function = a;
+	QString m = "";
+	switch(a){
+	case Preferences::Seeking:
+		m = tr("Mouse wheel seeks now");
+		break;
+	case Preferences::Volume:
+		m = tr("Mouse wheel changes volume now");
+		break;
+	case Preferences::Zoom:
+		m = tr("Mouse wheel changes zoom level now");
+		break;
+	case Preferences::ChangeSpeed:
+		m = tr("Mouse wheel changes speed now");
+		break;
+	}
+	displayMessage(m);
+}
+
 void Core::changeLetterbox(bool b) {
 	qDebug("Core::changeLetterbox: %d", b);
 
@@ -3206,114 +3400,11 @@ void Core::changeLetterbox(bool b) {
 	}
 }
 
-#else
-void Core::changeAspectRatio( int ID ) {
-	qDebug("Core::changeAspectRatio: %d", ID);
-
-	int old_id = mset.aspect_ratio_id;
-	mset.aspect_ratio_id = ID;
-	bool need_restart = FALSE;
-
-    double asp = mdat.video_aspect; // Set a default
-
-    if (ID==MediaSettings::Aspect43Letterbox) {  
-		need_restart = (old_id != MediaSettings::Aspect43Letterbox);
-		asp = (double) 4 / 3;
-        mset.letterbox = MediaSettings::Letterbox_43;
-		mset.panscan_filter = "";
-		mset.crop_43to169_filter = "";
-	}
-	else
-    if (ID==MediaSettings::Aspect169Letterbox) {  
-		need_restart = (old_id != MediaSettings::Aspect169Letterbox);
-		asp = (double) 16 / 9;
-        mset.letterbox = MediaSettings::Letterbox_169;
-		mset.panscan_filter = "";
-		mset.crop_43to169_filter = "";
-	}
-	else
-	if (ID==MediaSettings::Aspect43Panscan) {
-		need_restart = (old_id != MediaSettings::Aspect43Panscan);
-		mset.crop_43to169_filter = "";
-		mset.letterbox = MediaSettings::NoLetterbox;
-
-		asp = (double) 4 / 3;
-		int real_width = (int) round(mdat.video_height * mdat.video_aspect);
-		mset.panscan_filter = QString("scale=%1:%2,").arg(real_width).arg(mdat.video_height);
-		mset.panscan_filter += QString("crop=%1:%2").arg(round(mdat.video_height * 4 /3)).arg(mdat.video_height);
-		//mset.crop = QSize( mdat.video_height * 4 /3, mdat.video_height );
-		qDebug("Core::changeAspectRatio: panscan_filter = '%s'", mset.panscan_filter.toUtf8().data() );
-
-	}
-    else
-	if (ID==MediaSettings::Aspect43To169) {
-		need_restart = (old_id != MediaSettings::Aspect43To169);
-		mset.panscan_filter = "";
-		mset.crop_43to169_filter = "";
-		mset.letterbox = MediaSettings::NoLetterbox;
-
-		int real_width = (int) round(mdat.video_height * mdat.video_aspect);
-		int height = (int) round(real_width * 9 / 16);
-
-		qDebug("Core::changeAspectRatio: video_width: %d, video_height: %d", real_width, mdat.video_height);
-		qDebug("Core::changeAspectRatio: crop: %d, %d", real_width, height );
-
-		if (height > mdat.video_height) {
-			// Invalid size, source video is not 4:3
-			need_restart = FALSE;
-		} else {
-			asp = (double) 16 / 9;
-			mset.crop_43to169_filter = QString("scale=%1:%2,").arg(real_width).arg(mdat.video_height);
-			mset.crop_43to169_filter += QString("crop=%1:%2").arg(real_width).arg(height);
-			qDebug("Core::changeAspectRatio: crop_43to169_filter = '%s'", mset.crop_43to169_filter.toUtf8().data() );
-		}
-	}
-	else
-    {
-		//need_restart = (mset.force_letterbox == TRUE);
-		need_restart = ( (old_id == MediaSettings::Aspect43Letterbox) || 
-                         (old_id == MediaSettings::Aspect169Letterbox) || 
-                         (old_id == MediaSettings::Aspect43Panscan) || 
-                         (old_id == MediaSettings::Aspect43To169) );
-		mset.letterbox = MediaSettings::NoLetterbox;
-		mset.panscan_filter = "";
-		mset.crop_43to169_filter = "";
-        switch (ID) {
-        	//case MediaSettings::AspectAuto: asp = mdat.video_aspect; break;
-			case MediaSettings::AspectAuto: {
-				qDebug("Core::changeAspectRatio: mset.win_width %d, mset.win_height: %d", mset.win_width, mset.win_height);
-                asp = mset.win_aspect(); break;
-			}
-            case MediaSettings::Aspect43: asp = (double) 4 / 3; break;
-            case MediaSettings::Aspect169: asp = (double) 16 / 9; break;
-			case MediaSettings::Aspect149: asp = (double) 14 / 9; break;
-			case MediaSettings::Aspect1610: asp = (double) 16 / 10; break;
-			case MediaSettings::Aspect54: asp = (double) 5 / 4; break;
-            case MediaSettings::Aspect235: asp = 2.35; break;
-		}
-	}
-
-	if (!pref->use_mplayer_window) {
-		mplayerwindow->setAspect( asp );
-	} else {
-		// Using mplayer own window
-		tellmp("switch_ratio " + QString::number(asp));
-	}
-
-	updateWidgets();
-
-    if (need_restart) {
-		/*mdat.calculateWinResolution(mset.force_letterbox);*/
-    	restartPlay();
-	}
-}
-#endif
-
 void Core::changeOSD(int v) {
 	qDebug("Core::changeOSD: %d", v);
 
 	pref->osd = v;
-	tellmp("osd " + QString::number( pref->osd ) );
+	tellmp( pausing_prefix() + " osd " + QString::number( pref->osd ) );
 	updateWidgets();
 }
 
@@ -3640,7 +3731,8 @@ void Core::watchState(Core::State state) {
 	{
 		// Delayed volume change
 		qDebug("Core::watchState: delayed volume change");
-		tellmp("volume " + QString::number(mset.volume) + " 1");
+		int volume = (pref->global_volume ? pref->volume : mset.volume);
+		tellmp("volume " + QString::number(volume) + " 1");
 		change_volume_after_unpause = false;
 	}
 }
@@ -3784,7 +3876,18 @@ void Core::initSubtitleTrack(const SubTracks & subs) {
 			// The loaded subtitle file is the last one, so
 			// try to select that one.
 			if (mdat.subs.numItems() > 0) {
-				changeSubtitle( mdat.subs.numItems()-1 );
+				int selected_subtitle = mdat.subs.numItems()-1; // If everything fails, use the last one
+
+				// Try to find the subtitle file in the list
+				for (int n = 0; n < mdat.subs.numItems(); n++) {
+					SubData sub = mdat.subs.itemAt(n);
+					if ((sub.type() == SubData::File) && (sub.filename() == mset.external_subtitles)) {
+						selected_subtitle = n;
+						qDebug("Core::initSubtitleTrack: external subtitle found: #%d", n);
+						break;
+					}
+				}
+				changeSubtitle( selected_subtitle );
 				goto end;
 			}
 		}
@@ -3853,13 +3956,24 @@ void Core::askForInfo() {
 }
 
 void Core::dvdnavUpdateMousePos(QPoint pos) {
-	if ((state() == Playing) && (mdat.filename.startsWith("dvdnav:"))) {
+	if ((state() == Playing) && (mdat.filename.startsWith("dvdnav:")) && (dvdnav_title_is_menu)) {
 		if (mplayerwindow->videoLayer()->underMouse()) {
 			QPoint p = mplayerwindow->videoLayer()->mapFromParent(pos);
 			tellmp(QString("set_mouse_pos %1 %2").arg(p.x()).arg(p.y()));
 		}
 	}
 }
+
+void Core::dvdTitleIsMenu() {
+	qDebug("Core::dvdTitleIsMenu");
+	dvdnav_title_is_menu = true;
+}
+
+void Core::dvdTitleIsMovie() {
+	qDebug("Core::dvdTitleIsMovie");
+	dvdnav_title_is_menu = false;
+
+}
 #endif
 
 QString Core::pausing_prefix() {
