@@ -21,6 +21,8 @@
 
 SimpleHttp::SimpleHttp( QObject * parent ) : QHttp(parent)
 {
+	http_get_id = -1;
+
 	connect( this, SIGNAL(requestFinished(int, bool)),
              this, SLOT(httpRequestFinished(int, bool)) );
 
@@ -50,6 +52,12 @@ void SimpleHttp::readResponseHeader(const QHttpResponseHeader &responseHeader) {
 		download(new_url);
 	}
 	else
+	if (responseHeader.statusCode() == 302)  {
+		QString location = responseHeader.value("Location");
+		qDebug("SimpleHttp::readResponseHeader: Location: '%s'", location.toLatin1().constData());
+		http_get_id = get( location );
+	}
+	else
 	if (responseHeader.statusCode() != 200) {
 		qDebug("SimpleHttp::readResponseHeader: error: '%s'", responseHeader.reasonPhrase().toLatin1().constData());
 		emit downloadFailed(responseHeader.reasonPhrase());
@@ -58,7 +66,7 @@ void SimpleHttp::readResponseHeader(const QHttpResponseHeader &responseHeader) {
 }
 
 void SimpleHttp::httpRequestFinished(int request_id, bool error) {
-	qDebug("SimpleHttp::httpRequestFinished: %d, %d", request_id, error);
+	qDebug("SimpleHttp::httpRequestFinished: http_get_id: %d request_id: %d, error: %d", http_get_id, request_id, error);
 
     if (request_id != http_get_id) return;
 
