@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2009 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -52,9 +52,6 @@ public:
 	//! Change filenames like "C:/Program Files/" to "C:\Program Files\"
 	static QString changeSlashes(QString filename);
 
-	static QString dvdSplitFolder(QString dvd_url);
-	static int dvdSplitTitle(QString dvd_url);
-
 	static bool directoryContainsDVD(QString directory);
 
 	//! Returns an int with the version number of Qt at run-time.
