@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2009 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -33,6 +33,9 @@ public:
 	static QPixmap resize(QPixmap *p, int size=20);
 	static QPixmap flip(QPixmap *p);
 
+	//! Returns the filename of the icon
+	static QString file(const QString & icon_name);
+
 private:
 	//! Return the filename for the icon
 	static QString filename(const QString & name, bool png);
