@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2009 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -37,7 +37,8 @@ public:
 	bool isPlaylist();
 
 protected slots:
-	void indexChanged();
+	void indexChanged(int);
+	void textChanged(const QString &);
 	void playlistChanged(int);
 };
 
