@@ -220,6 +220,7 @@ QMap<QString,QString> Languages::translations() {
 	m["el_GR"] = tr("Greek");
 	m["en_US"] = tr("English");
 	m["es"] = tr("Spanish");
+	m["et"] = tr("Estonian");
 	m["eu"] = tr("Basque");
 	m["fi"] = tr("Finnish");
 	m["fr"] = tr("French");
@@ -234,7 +235,7 @@ QMap<QString,QString> Languages::translations() {
 	m["nl"] = tr("Dutch");
 	m["pl"] = tr("Polish");
 	m["pt_BR"] = tr("Portuguese - Brazil");
-	m["pt_PT"] = tr("Portuguese - Portugal");
+	m["pt"] = tr("Portuguese - Portugal");
 	m["ro_RO"] = tr("Romanian");
 	m["ru_RU"] = tr("Russian");
 	m["sk"] = tr("Slovak");
@@ -243,6 +244,7 @@ QMap<QString,QString> Languages::translations() {
 	m["sv"] = tr("Swedish");
 	m["tr"] = tr("Turkish");
 	m["uk_UA"] = tr("Ukrainian");
+	m["vi_VN"] = tr("Vietnamese");
 	m["zh_CN"] = tr("Simplified-Chinese");
 	m["zh_TW"] = tr("Traditional Chinese");
 
