@@ -40,6 +40,9 @@ void MediaData::reset() {
     video_height=0;
     video_aspect= (double) 4/3;
 
+#if PROGRAM_SWITCH
+	programs.clear();
+#endif
 	videos.clear();
 	audios.clear();
 	titles.clear();
@@ -123,6 +126,10 @@ void MediaData::list() {
 	qDebug("  Subs:");
 	subs.list();
 
+#if PROGRAM_SWITCH
+	qDebug("  Programs:");
+	programs.list();
+#endif
 	qDebug("  Videos:");
 	videos.list();
 
