@@ -34,6 +34,9 @@ void MediaSettings::reset() {
 	current_sec = 0;
 	//current_sub_id = SubNone; 
 	current_sub_id = NoneSelected;
+#if PROGRAM_SWITCH
+	current_program_id = NoneSelected;
+#endif
 	current_video_id = NoneSelected;
 	current_audio_id = NoneSelected;
 	current_title_id = NoneSelected;
@@ -74,13 +77,7 @@ void MediaSettings::reset() {
 	//current_deinterlacer = NoDeinterlace;
 	current_deinterlacer = pref->initial_deinterlace;
 
-#if NEW_ASPECT_CODE
 	add_letterbox = false;
-#else
-	letterbox = NoLetterbox;
-	panscan_filter = "";
-	crop_43to169_filter = "";
-#endif
 
     karaoke_filter = false;
 	extrastereo_filter = false;
@@ -119,8 +116,6 @@ double MediaSettings::win_aspect() {
 	return (double) win_width / win_height;
 }
 
-
-#if NEW_ASPECT_CODE
 double MediaSettings::aspectToNum(Aspect aspect) {
 	double asp;
 
@@ -133,6 +128,8 @@ double MediaSettings::aspectToNum(Aspect aspect) {
 		case MediaSettings::Aspect54: asp = (double) 5 / 4; break;
 		case MediaSettings::Aspect235: asp = 2.35; break;
 		case MediaSettings::Aspect11: asp = 1; break;
+		case MediaSettings::Aspect32: asp = (double) 3 / 2; break;
+		case MediaSettings::Aspect1410: asp = (double) 14 / 10; break;
 		case MediaSettings::AspectAuto: asp = win_aspect(); break;
 		default: asp = win_aspect(); 
                  qWarning("MediaSettings::aspectToNum: invalid aspect: %d", aspect);
@@ -153,19 +150,23 @@ QString MediaSettings::aspectToString(Aspect aspect) {
 		case MediaSettings::Aspect54: asp_name = "5:4"; break;
 		case MediaSettings::Aspect235: asp_name = "2.35:1"; break;
 		case MediaSettings::Aspect11: asp_name = "1:1"; break;
+		case MediaSettings::Aspect32: asp_name = "3:2"; break;
+		case MediaSettings::Aspect1410: asp_name = "14:10"; break;
 		case MediaSettings::AspectAuto: asp_name = QObject::tr("auto", "aspect_ratio"); break;
 		default: asp_name = QObject::tr("unknown", "aspect_ratio");
 	}
 
 	return asp_name;
 }
-#endif
 
 void MediaSettings::list() {
 	qDebug("MediaSettings::list");
 
 	qDebug("  current_sec: %f", current_sec);
 	qDebug("  current_sub_id: %d", current_sub_id);
+#if PROGRAM_SWITCH
+	qDebug("  current_program_id: %d", current_program_id);
+#endif
 	qDebug("  current_video_id: %d", current_video_id);
 	qDebug("  current_audio_id: %d", current_audio_id);
 	qDebug("  current_title_id: %d", current_title_id);
@@ -201,13 +202,9 @@ void MediaSettings::list() {
 	qDebug("  upscaling_filter: %d", upscaling_filter);
 
 	qDebug("  current_deinterlacer: %d", current_deinterlacer);
-#if NEW_ASPECT_CODE
+
 	qDebug("  add_letterbox: %d", add_letterbox);
-#else
-	qDebug("  letterbox: %d", letterbox);
-	qDebug("  panscan_filter: '%s'", panscan_filter.toUtf8().data());
-	qDebug("  crop_43to169_filter: '%s'", crop_43to169_filter.toUtf8().data());
-#endif
+
 	qDebug("  karaoke_filter: %d", karaoke_filter);
 	qDebug("  extrastereo_filter: %d", extrastereo_filter);
 	qDebug("  volnorm_filter: %d", volnorm_filter);
@@ -251,6 +248,9 @@ void MediaSettings::save(QSettings * set) {
 
 	set->setValue( "current_sec", current_sec );
 	set->setValue( "current_sub_id", current_sub_id );
+#if PROGRAM_SWITCH
+	set->setValue( "current_program_id", current_program_id );
+#endif
 	set->setValue( "current_video_id", current_video_id );
 	set->setValue( "current_audio_id", current_audio_id );
 	set->setValue( "current_title_id", current_title_id );
@@ -288,13 +288,9 @@ void MediaSettings::save(QSettings * set) {
 	set->setValue( "upscaling_filter", upscaling_filter);
 
 	set->setValue( "current_deinterlacer", current_deinterlacer);
-#if NEW_ASPECT_CODE
+
 	set->setValue( "add_letterbox", add_letterbox );
-#else
-	set->setValue( "letterbox", letterbox );
-	set->setValue( "panscan_filter", panscan_filter);
-	set->setValue( "crop_43to169_filter", crop_43to169_filter);
-#endif
+
 	set->setValue( "karaoke_filter", karaoke_filter);
 	set->setValue( "extrastereo_filter", extrastereo_filter);
 	set->setValue( "volnorm_filter", volnorm_filter);
@@ -339,6 +335,9 @@ void MediaSettings::load(QSettings * set) {
 
 	current_sec = set->value( "current_sec", current_sec).toDouble();
 	current_sub_id = set->value( "current_sub_id", current_sub_id ).toInt();
+#if PROGRAM_SWITCH
+	current_program_id = set->value( "current_program_id", current_program_id ).toInt();
+#endif
 	current_video_id = set->value( "current_video_id", current_video_id ).toInt();
 	current_audio_id = set->value( "current_audio_id", current_audio_id ).toInt();
 	current_title_id = set->value( "current_title_id", current_title_id ).toInt();
@@ -376,13 +375,9 @@ void MediaSettings::load(QSettings * set) {
 	upscaling_filter = set->value( "upscaling_filter", upscaling_filter).toBool();
 
 	current_deinterlacer = set->value( "current_deinterlacer", current_deinterlacer ).toInt();
-#if NEW_ASPECT_CODE
+
 	add_letterbox = set->value( "add_letterbox", add_letterbox ).toBool();
-#else
-	letterbox = (LetterboxType) set->value( "letterbox", letterbox ).toInt();
-	panscan_filter = set->value( "panscan_filter", panscan_filter).toString();
-	crop_43to169_filter = set->value( "crop_43to169_filter", crop_43to169_filter).toString();
-#endif
+
 	karaoke_filter = set->value( "karaoke_filter", karaoke_filter).toBool();
 	extrastereo_filter = set->value( "extrastereo_filter", extrastereo_filter).toBool();
 	volnorm_filter = set->value( "volnorm_filter", volnorm_filter).toBool();
