@@ -24,7 +24,7 @@
 #include "global.h"
 #include "preferences.h"
 #include "mplayerversion.h"
-#include "helper.h"
+#include "colorutils.h"
 
 using namespace Global;
 
@@ -117,6 +117,8 @@ static QRegExp rx_fontcache("^\\[ass\\] Updating font cache|^\\[ass\\] Init");
 #if DVDNAV_SUPPORT
 static QRegExp rx_dvdnav_switch_title("^DVDNAV, switched to title: (\\d+)");
 static QRegExp rx_dvdnav_length("^ANS_length=(.*)");
+static QRegExp rx_dvdnav_title_is_menu("^DVDNAV_TITLE_IS_MENU");
+static QRegExp rx_dvdnav_title_is_movie("^DVDNAV_TITLE_IS_MOVIE");
 #endif
  
 // VCD
@@ -136,6 +138,10 @@ static QRegExp rx_audio("^ID_AUDIO_ID=(\\d+)");
 static QRegExp rx_audio_info("^ID_AID_(\\d+)_(LANG|NAME)=(.*)");
 #endif
 
+#if PROGRAM_SWITCH
+static QRegExp rx_program("^PROGRAM_ID=(\\d+)");
+#endif
+
 //Clip info
 static QRegExp rx_clip_name("^ (name|title): (.*)", Qt::CaseInsensitive);
 static QRegExp rx_clip_artist("^ artist: (.*)", Qt::CaseInsensitive);
@@ -158,7 +164,7 @@ void MplayerProcess::parseLine(QByteArray ba) {
 	QString value;
 
 #if COLOR_OUTPUT_SUPPORT
-    QString line = Helper::stripColorsTags(QString::fromLocal8Bit(ba));
+    QString line = ColorUtils::stripColorsTags(QString::fromLocal8Bit(ba));
 #else
 	QString line = QString::fromLocal8Bit(ba);
 #endif
@@ -384,6 +390,12 @@ void MplayerProcess::parseLine(QByteArray ba) {
 				emit receivedDuration(length);
 			}
 		}
+		if (rx_dvdnav_title_is_menu.indexIn(line) > -1) {
+			emit receivedTitleIsMenu();
+		}
+		if (rx_dvdnav_title_is_movie.indexIn(line) > -1) {
+			emit receivedTitleIsMovie();
+		}
 #endif
 
 		// The following things are not sent when the file has started to play
@@ -439,6 +451,16 @@ void MplayerProcess::parseLine(QByteArray ba) {
 		else
 #endif
 
+#if PROGRAM_SWITCH
+		// Program
+		if (rx_program.indexIn(line) > -1) {
+			int ID = rx_program.cap(1).toInt();
+			qDebug("MplayerProcess::parseLine: Program: ID: %d", ID);
+			md.programs.addID( ID );
+		}
+		else
+#endif
+
 		// Video tracks
 		if (rx_video.indexIn(line) > -1) {
 			int ID = rx_video.cap(1).toInt();
