@@ -80,6 +80,10 @@ Playlist::Playlist( Core *c, QWidget * parent, Qt::WindowFlags f)
 #endif
 	play_files_from_start = true;
 
+	automatically_play_next = true;
+
+	row_spacing = -1; // Default height
+
 	modified = false;
 
 	core = c;
@@ -121,6 +125,11 @@ Playlist::Playlist( Core *c, QWidget * parent, Qt::WindowFlags f)
 
 	loadSettings();
 
+	// Ugly hack to avoid to play next item automatically
+	if (!automatically_play_next) {
+		disconnect( core, SIGNAL(mediaFinished()), this, SLOT(playNext()) );
+	}
+
 	// Save config every 5 minutes.
 	save_timer = new QTimer(this);
 	connect( save_timer, SIGNAL(timeout()), this, SLOT(maybeSaveSettings()) );
@@ -361,6 +370,8 @@ void Playlist::updateView() {
 		} else {
 			listView->setIcon(n, COL_PLAY, QPixmap() );
 		}
+
+		if (row_spacing > -1) listView->setRowHeight(n, listView->font().pointSize() + row_spacing);
 	}
 	//listView->resizeColumnsToContents();
 	listView->resizeColumnToContents(COL_PLAY);
@@ -533,10 +544,15 @@ void Playlist::load_m3u(QString file) {
 void Playlist::load_pls(QString file) {
 	qDebug("Playlist::load_pls");
 
+	if (!QFile::exists(file)) {
+		qDebug("Playlist::load_pls: '%s' doesn't exist, doing nothing", file.toUtf8().constData());
+		return;
+	}
+
 	playlist_path = QFileInfo(file).path();
 
 	QSettings set(file, QSettings::IniFormat);
-	set.beginGroup( "playlist");
+	set.beginGroup("playlist");
 
 	if (set.status() == QSettings::NoError) {
 		clear();
@@ -1247,6 +1263,9 @@ void Playlist::saveSettings() {
 	set->setValue( "recursive_add_directory", recursive_add_directory );
 	set->setValue( "save_playlist_in_config", save_playlist_in_config );
 	set->setValue( "play_files_from_start", play_files_from_start );
+	set->setValue( "automatically_play_next", automatically_play_next );
+
+	set->setValue( "row_spacing", row_spacing );
 
 #if !DOCK_PLAYLIST
 	set->setValue( "size", size() );
@@ -1286,6 +1305,9 @@ void Playlist::loadSettings() {
 	recursive_add_directory = set->value( "recursive_add_directory", recursive_add_directory ).toBool();
 	save_playlist_in_config = set->value( "save_playlist_in_config", save_playlist_in_config ).toBool();
 	play_files_from_start = set->value( "play_files_from_start", play_files_from_start ).toBool();
+	automatically_play_next = set->value( "automatically_play_next", automatically_play_next ).toBool();
+
+	row_spacing = set->value( "row_spacing", row_spacing ).toInt();
 
 #if !DOCK_PLAYLIST
 	resize( set->value("size", size()).toSize() );
