@@ -28,6 +28,7 @@
 #include "prefsubtitles.h"
 #include "prefadvanced.h"
 #include "prefplaylist.h"
+#include "preftv.h"
 
 #if USE_ASSOCIATIONS
 #include "prefassociations.h"
@@ -84,6 +85,9 @@ PreferencesDialog::PreferencesDialog(QWidget * parent, Qt::WindowFlags f)
 	page_playlist = new PrefPlaylist;
 	addSection( page_playlist );
 
+	page_tv = new PrefTV;
+	addSection( page_tv );
+
 #if USE_ASSOCIATIONS
 	page_associations = new PrefAssociations;
 	addSection(page_associations);
@@ -168,6 +172,7 @@ void PreferencesDialog::setData(Preferences * pref) {
 	page_subtitles->setData(pref);
 	page_advanced->setData(pref);
 	page_playlist->setData(pref);
+	page_tv->setData(pref);
 
 #if USE_ASSOCIATIONS
 	page_associations->setData(pref);
@@ -183,6 +188,7 @@ void PreferencesDialog::getData(Preferences * pref) {
 	page_subtitles->getData(pref);
 	page_advanced->getData(pref);
 	page_playlist->getData(pref);
+	page_tv->getData(pref);
 
 #if USE_ASSOCIATIONS
 	page_associations->getData(pref);
@@ -198,6 +204,7 @@ bool PreferencesDialog::requiresRestart() {
 	if (!need_restart) need_restart = page_subtitles->requiresRestart();
 	if (!need_restart) need_restart = page_advanced->requiresRestart();
 	if (!need_restart) need_restart = page_playlist->requiresRestart();
+	if (!need_restart) need_restart = page_tv->requiresRestart();
 
 	return need_restart;
 }
