@@ -77,13 +77,13 @@ void PrefPerformance::setData(Preferences * pref) {
 	setCacheForDVDs( pref->cache_for_dvds );
 	setCacheForAudioCDs( pref->cache_for_audiocds );
 	setCacheForVCDs( pref->cache_for_vcds );
+	setCacheForTV( pref->cache_for_tv );
 
 	setPriority( pref->priority );
 	setFrameDrop( pref->frame_drop );
 	setHardFrameDrop( pref->hard_frame_drop );
+	setCoreavcUsage( pref->coreavc );
 	setSkipLoop( pref->h264_skip_loop_filter );
-	setAutoSyncActivated( pref->autosync );
-	setAutoSyncFactor( pref->autosync_factor );
 #if !SMART_DVD_CHAPTERS
 	setFastChapterSeeking( pref->fast_chapter_change );
 #endif
@@ -99,13 +99,13 @@ void PrefPerformance::getData(Preferences * pref) {
 	TEST_AND_SET(pref->cache_for_dvds, cacheForDVDs());
 	TEST_AND_SET(pref->cache_for_audiocds, cacheForAudioCDs());
 	TEST_AND_SET(pref->cache_for_vcds, cacheForVCDs());
+	TEST_AND_SET(pref->cache_for_tv, cacheForTV());
 
 	TEST_AND_SET(pref->priority, priority());
 	TEST_AND_SET(pref->frame_drop, frameDrop());
 	TEST_AND_SET(pref->hard_frame_drop, hardFrameDrop());
+	TEST_AND_SET(pref->coreavc, coreavcUsage())
 	TEST_AND_SET(pref->h264_skip_loop_filter, skipLoop());
-	TEST_AND_SET(pref->autosync, autoSyncActivated());
-	TEST_AND_SET(pref->autosync_factor, autoSyncFactor());
 #if !SMART_DVD_CHAPTERS
 	TEST_AND_SET(pref->fast_chapter_change, fastChapterSeeking());
 #endif
@@ -153,6 +153,14 @@ int PrefPerformance::cacheForVCDs() {
 	return cache_vcds_spin->value();
 }
 
+void PrefPerformance::setCacheForTV(int n) {
+	cache_tv_spin->setValue(n);
+}
+
+int PrefPerformance::cacheForTV() {
+	return cache_tv_spin->value();
+}
+
 void PrefPerformance::setPriority(int n) {
 	priority_combo->setCurrentIndex(n);
 }
@@ -177,6 +185,14 @@ bool PrefPerformance::hardFrameDrop() {
 	return hardframedrop_check->isChecked();
 }
 
+void PrefPerformance::setCoreavcUsage(bool b) {
+	coreavc_check->setChecked(b);
+}
+
+bool PrefPerformance::coreavcUsage() {
+	return coreavc_check->isChecked();
+}
+
 void PrefPerformance::setSkipLoop(Preferences::H264LoopFilter value) {
 	loopfilter_combo->setCurrentIndex(loopfilter_combo->findData(value));
 }
@@ -185,22 +201,6 @@ Preferences::H264LoopFilter PrefPerformance::skipLoop() {
 	return (Preferences::H264LoopFilter) loopfilter_combo->itemData(loopfilter_combo->currentIndex()).toInt();
 }
 
-void PrefPerformance::setAutoSyncFactor(int factor) {
-	autosync_spin->setValue(factor);
-}
-
-int PrefPerformance::autoSyncFactor() {
-	return autosync_spin->value();
-}
-
-void PrefPerformance::setAutoSyncActivated(bool b) {
-	autosync_check->setChecked(b);
-}
-
-bool PrefPerformance::autoSyncActivated() {
-	return autosync_check->isChecked();
-}
-
 #if !SMART_DVD_CHAPTERS
 void PrefPerformance::setFastChapterSeeking(bool b) {
 	fast_chapter_check->setChecked(b);
@@ -251,6 +251,9 @@ void PrefPerformance::createHelp() {
 		tr("Sets the number of threads to use for decoding. Only for "
            "MPEG-1/2 and H.264") );
 
+	setWhatsThis(coreavc_check, tr("Use CoreAVC if no other codec specified"),
+		tr("Try to use non-free CoreAVC codec with no other codec is specified and non-VDPAU video output selected. Requires MPlayer build with CoreAVC support."));
+
 	setWhatsThis(loopfilter_combo, tr("Skip loop filter"),
 		tr("This option allows to skips the loop filter (AKA deblocking) "
            "during H.264 decoding. "
@@ -267,10 +270,6 @@ void PrefPerformance::createHelp() {
            "skipped only on videos which height is %1 or "
            "greater.").arg(pref->HD_height) +"<br>" );
 
-	setWhatsThis(autosync_check, tr("Audio/video auto synchronization"),
-		tr("Gradually adjusts the A/V sync based on audio delay "
-           "measurements.") );
-
 	setWhatsThis(fast_audio_combo, tr("Fast audio track switching"),
 		tr("Possible values:<br> "
            "<b>Yes</b>: it will try the fastest method "
