@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2009 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -31,10 +31,12 @@ public:
 
 	int time();
 	int maximumTime();
+	QString label();
 
 public slots:
 	void setTime(int seconds);
 	void setMaximumTime( int seconds );
+	void setLabel(const QString & label);
 };
 
 #endif
