@@ -29,6 +29,7 @@ class QLabel;
 class QScrollArea;
 class QDialogButtonBox;
 class QSettings;
+class QAction;
 
 class VideoInfo 
 {
@@ -108,6 +109,7 @@ public:
 protected slots:
 	void cancelPressed();
 	void saveImage();
+	void showInfo(bool visible); 
 
 protected:
 	virtual void retranslateStrings();
@@ -143,6 +145,8 @@ protected:
 
 	QSettings * set;
 
+	QAction * toggleInfoAct;
+
 	struct Properties {
 		QString input_video;
 		QString dvd_device;
